@@ -2,6 +2,7 @@
 import dataclasses
 import logging
 import os.path
+import pathlib
 import re
 import typing
 import uuid
@@ -161,14 +162,17 @@ def construct_include(loader, node):
     """Include file referenced at node."""
 
     filename = find_include(loader, node)
-    extension = os.path.splitext(filename)[1].lstrip(".")
+    resolved_path = pathlib.Path(filename)
+    extension = resolved_path.suffix.lstrip(".").lower()
 
-    if extension not in ("yaml", "yml", "json"):
-        raise BadSchemaError(
-            f"Unknown filetype '{filename}' (included files must be in YAML format and end with .yaml or .yml)"
-        )
+    if extension in ("yaml", "yml", "json"):
+        return load_single_document_yaml(filename)
+    elif extension == "graphql":
+        return resolved_path.read_text(encoding="utf-8")
 
-    return load_single_document_yaml(filename)
+    raise BadSchemaError(
+        f"Unknown filetype '{filename}' (included files must be in YAML, JSON, or GraphQL format with extensions .yaml, .yml, .json, or .graphql)"
+    )
 
 
 IncludeLoader.add_constructor("!include", construct_include)
@@ -286,6 +290,8 @@ class AnythingSentinel(TypeSentinel):
     yaml_tag = "!anything"
     constructor = str
 
+    allowed_types = "<anything>"
+
     @classmethod
     def from_yaml(cls, loader, node):
         return ANYTHING
